@@ -79,10 +79,6 @@ class Download:
             "album_id": str(self.album['album_id']),
             "artist_id": str(self.album['artist_id']),
             "type": self.album['album_tp'],
-            "agency_name": self.album['agency_nm'],
-            "agency_id": str(self.album['agency_id']),
-            "label_name": self.album['labels'][0]['label_nm'],
-            "label_id": str(self.album['labels'][0]['label_id'])
         }
         template = self.settings['template']
         for k in keys:
